@@ -274,6 +274,11 @@ def _get_xlsx_keys(path: str,
     wb = load_workbook(path, data_only=True, read_only=True)
     ws = wb.active
 
+    if ws.max_column is None:  # 遇到过read_only时无法获取列数的文件
+        wb.close()
+        wb = load_workbook(path, data_only=True)
+        ws = wb.active
+
     if sign_col > ws.max_column:
         res_keys = [[ind] + [i.value for k, i in enumerate(row, 1) if k in key_cols]
                     for ind, row in enumerate(ws.rows, 1) if ind >= begin_row]
